xquery version "3.1";

declare namespace bibo="http://purl.org/ontology/bibo/";
declare namespace bf="http://bibframe.org/vocab/";
declare namespace dc="http://purl.org/dc/elements/1.1/";
declare namespace dcterms="http://purl.org/dc/terms/";
declare namespace gndo="http://d-nb.info/standards/elementset/gnd#";
declare namespace rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#";
declare namespace marc21="http://www.loc.gov/MARC21/slim";
declare namespace owl="http://www.w3.org/2002/07/owl#";
declare namespace rdagr1="http://rdvocab.info/Elements/";
declare namespace http="http://expath.org/ns/http-client";
declare namespace bdn="http://www.bdn-edition/biblmodel#";

declare option exist:serialize "method=html version=5.0 html-version=5.0 media-type=text/html";

import module namespace config="https://sade.textgrid.de/ns/config" at "../modules/config.xqm";
import module namespace functx="http://www.functx.com";
import module namespace rdfm="https://sade.textgrid.de/ns/rdf" at "../modules/rdf.xqm";

let $id := request:get-parameter("id", "")
let $instance-description := rdfm:get-doc($id)/rdf:RDF/rdf:Description
let $book-description := rdfm:get-doc($instance-description/bdn:instantiates/@rdf:resource/string())/rdf:RDF/rdf:Description

let $creators := $book-description/dcterms:creator/@rdf:resource/string() (: sequence of strings :)
let $creators-docs := fn:for-each($creators, rdfm:get-doc(?)) (: sequence of docs :)
let $creators-html :=
  fn:for-each(
    $creators-docs,
    function($p1)
    {
      (: the person's name :)
      $p1/rdf:RDF/rdf:Description/gndo:preferredNameForThePerson/text(),
      element span {
        attribute class { "fa-user-link" },
        (: uri to the person's rdf :)
        attribute tguri {
          $p1/rdf:RDF/rdf:Description/@rdf:about/string() => functx:substring-after-last("/")
        },
        attribute id { util:uuid() },
        element i {
          attribute class { "fas fa-user" }
        }
      }
    }
  )

return
  <div class="modal fade" role="dialog">
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal">
          × <!-- times -->
        </button>
        <h4 class="modal-title">
          <i class="fas fa-book" /> Bibliographische Informationen
        </h4>
        </div>
        <div class="modal-body">
        <table>
          <tr>
            <td>Titel:</td>
            <td>{$book-description/dcterms:title/text()}</td>
          </tr>
          <tr>
            <td>Autor(en):</td>
            <td>
              <div>{$creators-html}</div>
            </td>
          </tr>
          <tr>
            <td>Ort/Jahr:</td>
            <td>{$instance-description/rdagr1:placeOfPublication/text()}/{$instance-description/rdagr1:dateOfPublication/text()}</td>
          </tr>
          <tr>
            <td>Auflage:</td>
            <td>{$instance-description/bf:edition/text()}</td>
          </tr>
          <tr>
            <td>Verlag/Drucker:</td>
            <td>{$instance-description/bf:providerStatement/text()}</td>
          </tr>
        </table>

        <span class="source">Quelle:
          <a href="{$instance-description/owl:sameAs/@rdf:resource/string()}" target="_blank">{$instance-description/owl:sameAs/@rdf:resource/string()}</a>
        </span>
      </div>
    </div>
    </div>
  </div>
